@@ -16,7 +16,7 @@ package Lucy::Build::Binding::Document;
 use strict;
 use warnings;
 
-our $VERSION = '0.004099_002';
+our $VERSION = '0.005000';
 $VERSION = eval $VERSION;
 
 sub bind_all {
@@ -63,6 +63,13 @@ B<field> - The field name.
 B<value> - The value.
 
 =back
+END_POD
+    my $get_fields_pod = <<'END_POD';
+=head2 get_fields
+
+    my $hashref = $doc->get_fields();
+
+Return the Doc's backing fields hash.
 END_POD
     $pod_spec->set_synopsis($synopsis);
     $pod_spec->add_constructor( alias => 'new', sample => $constructor );
@@ -74,6 +81,7 @@ END_POD
     $pod_spec->add_method(
         method => 'Get_Fields',
         alias  => 'get_fields',
+        pod    => $get_fields_pod,
     );
 
     my $xs_code = <<'END_XS_CODE';
